@@ -1,15 +1,28 @@
 coerce_content <- function(x) {
-  if (length(x) > 0) {
-    if (is_tag(x)) {
-      HTML(as.character(x))
-    } else {
-      HTML(paste(
-        vapply(x, function(i) HTML(as.character(i)), character(1)),
-        collapse = "\n"
-      ))
-    }
+  if (is.null(x)) {
+    return(NULL)
+  }
+
+  if (length(x) == 0) {
+    return(list())
+  }
+
+  if (is_tag(x)) {
+    HTML(as.character(x))
+  } else if (inherits(x, "AsIs")) {
+    HTML(
+      paste(
+        vapply(x, as.character, character(1)),
+        collapse = "<br>\n"
+      )
+    )
   } else {
-    ""
+    HTML(
+      paste(
+        vapply(x, as.character, character(1)),
+        collapse = "\n"
+      )
+    )
   }
 }
 
@@ -17,16 +30,16 @@ coerce_selected <- function(x) {
   if (is.null(x)) {
     x
   } else if (isTRUE(x)) {
-    x
+    TRUE
   } else {
-    lapply(x, as.character)
+    unname(lapply(x, as.character))
   }
 }
 
 coerce_enable <- function(x) {
   if (!is.null(x)) {
     if (!isTRUE(x)) {
-      lapply(x, function(i) HTML(as.character(i)))
+      lapply(x, as.character)
     } else {
       x
     }
@@ -36,7 +49,7 @@ coerce_enable <- function(x) {
 coerce_disable <- function(x) {
   if (!is.null(x)) {
     if (!isTRUE(x)) {
-      lapply(x, function(i) HTML(as.character(i)))
+      lapply(x, as.character)
     } else {
       x
     }
@@ -54,3 +67,11 @@ coerce_invalid <- function(x) {
     HTML(as.character(x))
   }
 }
+
+coerce_submit <- function(x) {
+  if (identical(as.logical(x), FALSE)) {
+    NULL
+  } else {
+    x
+  }
+}
