@@ -4,7 +4,9 @@ test_that("choices and value may be NULL", {
   expect_silent(checkboxInput("ID"))
 })
 
-test_that("id must be NULL or character", {
+test_that("id argument", {
+  expect_missing_id_error(checkboxInput())
+
   expect_silent(checkboxInput("ID"))
   expect_silent(checkboxInput(NULL))
 
@@ -17,3 +19,7 @@ test_that("choices and values must be the same length", {
   expect_error(checkboxInput("ID", c("hello"), c("world", "moon")))
   expect_error(checkboxInput("ID", c("hello", "goodnight"), "world"))
 })
+
+test_that("has dependencies", {
+  expect_dependencies(checkboxInput("ID"))
+})
